# PyBadge

[![GitHub][github_badge]][github_link] [![PyPI][pypi_badge]][pypi_link]

Generate your badges in seconds.




## Installation

```bash
pip install pybadge
```



## Quickstart

```python
import pybadge
```



## License

PyBadge has a BSD license, as found in the [LICENSE](https://github.com/imyizhang/pybadge/blob/main/LICENSE) file.



## Contributing



## Changelog



[github_badge]: https://badgen.net/badge/icon/GitHub?icon=github&color=black&label
[github_link]: https://github.com/imyizhang/pybadge



[pypi_badge]: https://badgen.net/pypi/v/pybadge?icon=pypi&color=black&label
[pypi_link]: https://www.pypi.org/project/pybadge